@@ -6,6 +6,8 @@ from fastapi import (
 from ormar import Model
 from fastapi_helpers.crud import BaseCrud
 from .Paginate import Pagination
+from orjson import dumps
+
 
 
 class DefaultModelRouter():
@@ -14,6 +16,9 @@ class DefaultModelRouter():
     crud: BaseCrud
     model: Model
     headers: Dict
+    NOT_FOUND_ERR = {
+        "status": "not found"
+    }
 
     def __init__(
         self,
@@ -23,12 +28,13 @@ class DefaultModelRouter():
     ) -> None:
         self.model = model
         self.crud = crud
+        id_label = "/{id}/"
         self.router = APIRouter()
         self.router.add_api_route("/", self.read_list, methods=["GET"])
-        self.router.add_api_route("/{id}/", self.read, methods=["GET"])
+        self.router.add_api_route(id_label, self.read, methods=["GET"])
         self.router.add_api_route("/", self.create, methods=["POST"])
-        self.router.add_api_route("/{id}/", self.update, methods=["PUT"])
-        self.router.add_api_route("/{id}/", self.delete, methods=["DELETE"])
+        self.router.add_api_route(id_label, self.update, methods=["PUT"])
+        self.router.add_api_route(id_label, self.delete, methods=["DELETE"])
         self.headers = headers
 
     async def read_list(
@@ -48,10 +54,10 @@ class DefaultModelRouter():
     ) -> Optional[Union[Model, Dict]]:
         m = await self.crud.get(id=id)
         if(m is None):
-            raise HTTPException(404, {
-                "status": "not found"
-            }, self.headers)
-        return Response(m, status.HTTP_200_OK, self.headers, "")
+            raise HTTPException(404, self.NOT_FOUND_ERR, self.headers)
+        if(isinstance(m, Model)):
+            return Response(dumps(m.dict()), status.HTTP_200_OK, self.headers)
+        return Response(dumps(m), status.HTTP_200_OK, self.headers)
 
     async def create(
         self,
@@ -61,7 +67,9 @@ class DefaultModelRouter():
         m = await self.crud.create(
             model_in
         )
-        return Response(m, status.HTTP_201_CREATED, self.headers, )
+        if(isinstance(m, Model)):
+            return Response(dumps(m.dict()), status.HTTP_201_CREATED, self.headers)
+        return Response(dumps(m), status.HTTP_201_CREATED, self.headers,)
 
     async def update(
         self,
@@ -74,11 +82,11 @@ class DefaultModelRouter():
             model_in
         )
         if(m is None):
-            raise HTTPException(404, {
-                "status": "not found"
-            }, self.headers)
+            raise HTTPException(404, self.NOT_FOUND_ERR, self.headers)
+        if(isinstance(m, Model)):
+            return Response(dumps(m.dict()), status.HTTP_202_ACCEPTED, self.headers)
         return Response(
-            m, status.HTTP_201_CREATED, self.headers
+            dumps(m), status.HTTP_202_ACCEPTED, self.headers
         )
 
     async def delete(
@@ -90,13 +98,9 @@ class DefaultModelRouter():
             id=id,
         )
         if(m is None):
-            return Response(
-                {
-                    "status": "not found"
-                },
-                status.HTTP_404_NOT_FOUND,
-                self.headers
-            )
+            raise HTTPException(404, self.NOT_FOUND_ERR, self.headers)
+        if(isinstance(m, Model)):
+            return Response(dumps(m.dict()), status.HTTP_202_ACCEPTED, self.headers)
         return Response(
-            m, status.HTTP_202_ACCEPTED, self.headers
+            dumps(m), status.HTTP_202_ACCEPTED, self.headers
         )
